@@ -30,6 +30,7 @@
 /* solaris is broken otherwise */
 #if defined(__sun)
 #define _XPG4_2
+#define __EXTENSIONS__
 #endif
 
 #include <sys/types.h>
@@ -69,7 +70,7 @@
 
 /** power-of-2 alignment */
 #ifndef CUSTOM_ALIGN
-#define CUSTOM_ALIGN(x, a) (((unsigned long)(x) + (a) - 1) & ~((a) - 1))
+#define CUSTOM_ALIGN(x, a) (((uintptr_t)(x) + (uintptr_t)(a) - 1) & ~((uintptr_t)(a) - 1))
 #endif
 
 /** preferred alignment */
@@ -122,6 +123,8 @@
 #define _UNUSED                 __attribute__((unused))
 /** Do not inline function. */
 #define _NOINLINE               __attribute__((noinline))
+/** Indicates that function never returns */
+#define _NORETURN               __attribute__((noreturn))
 
 /* compiler hints - those do not seem to work well */
 #define unlikely(x) __builtin_expect(!!(x), 0)
@@ -135,6 +138,7 @@
 #define _MALLOC
 #define _UNUSED
 #define _NOINLINE
+#define _NORETURN
 #define unlikely(x) x
 #define likely(x) x
 
