@@ -509,7 +509,7 @@ bool check_fast_fail(PgSocket *client)
 	cnt = pool_server_count(pool) - statlist_count(&pool->new_server_list);
 	if (cnt)
 		return true;
-	disconnect_client(client, true, "no working server connection");
+	disconnect_client(client, true, "pgbouncer cannot connect to server");
 
 	/* usual relaunch wont work, as there are no waiting clients */
 	launch_new_connection(pool);
@@ -669,7 +669,7 @@ bool release_server(PgSocket *server)
 		fatal("bad server state in release_server (%d)", server->state);
 	}
 
-	/* enforce lifetime immidiately on release */
+	/* enforce lifetime immediately on release */
 	if (server->state != SV_LOGIN && life_over(server)) {
 		disconnect_server(server, true, "server_lifetime");
 		pool->last_lifetime_disconnect = get_cached_time();
@@ -844,6 +844,7 @@ static void dns_callback(void *arg, const struct sockaddr *sa, int salen)
 	struct PgSocket *server = arg;
 	struct PgDatabase *db = server->pool->db;
 	struct sockaddr_in sa_in;
+	struct sockaddr_in6 sa_in6;
 
 	server->dns_token = NULL;
 
@@ -858,8 +859,16 @@ static void dns_callback(void *arg, const struct sockaddr *sa, int salen)
 		salen = sizeof(sa_in);
 		slog_debug(server, "dns_callback: inet4: %s",
 			   sa2str(sa, buf, sizeof(buf)));
+	} else if (sa->sa_family == AF_INET6) {
+		char buf[64];
+		memcpy(&sa_in6, sa, sizeof(sa_in6));
+		sa_in6.sin6_port = htons(db->port);
+		sa = (struct sockaddr *)&sa_in6;
+		salen = sizeof(sa_in6);
+		slog_debug(server, "dns_callback: inet6: %s",
+			   sa2str(sa, buf, sizeof(buf)));
 	} else {
-		disconnect_server(server, true, "unknown dns type");
+		disconnect_server(server, true, "unknown address family: %d", sa->sa_family);
 		return;
 	}
 
@@ -1246,11 +1255,49 @@ void for_each_server(PgPool *pool, void (*func)(PgSocket *sk))
 		func(container_of(item, PgSocket, head));
 }
 
+static void for_each_server_filtered(PgPool *pool, void (*func)(PgSocket *sk), bool (*filter)(PgSocket *sk, void *arg), void *filter_arg)
+{
+	struct List *item;
+	PgSocket *sk;
+
+	statlist_for_each(item, &pool->idle_server_list) {
+		sk = container_of(item, PgSocket, head);
+		if (filter(sk, filter_arg))
+			func(sk);
+	}
+
+	statlist_for_each(item, &pool->used_server_list) {
+		sk = container_of(item, PgSocket, head);
+		if (filter(sk, filter_arg))
+			func(sk);
+	}
+
+	statlist_for_each(item, &pool->tested_server_list) {
+		sk = container_of(item, PgSocket, head);
+		if (filter(sk, filter_arg))
+			func(sk);
+	}
+
+	statlist_for_each(item, &pool->active_server_list) {
+		sk = container_of(item, PgSocket, head);
+		if (filter(sk, filter_arg))
+			func(sk);
+	}
+
+	statlist_for_each(item, &pool->new_server_list) {
+		sk = container_of(item, PgSocket, head);
+		if (filter(sk, filter_arg))
+			func(sk);
+	}
+}
+
+
 static void tag_dirty(PgSocket *sk)
 {
 	sk->close_needed = 1;
 }
 
+
 void tag_database_dirty(PgDatabase *db)
 {
 	struct List *item;
@@ -1263,6 +1310,30 @@ void tag_database_dirty(PgDatabase *db)
 	}
 }
 
+static bool server_remote_addr_filter(PgSocket *sk, void *arg) {
+	PgAddr *addr = arg;
+
+	return (pga_cmp_addr(&sk->remote_addr, addr) == 0);
+}
+
+void tag_host_addr_dirty(const char *host, const struct sockaddr *sa)
+{
+	struct List *item;
+	PgPool *pool;
+	PgAddr addr;
+
+	memset(&addr, 0, sizeof(addr));
+	pga_copy(&addr, sa);
+
+	statlist_for_each(item, &pool_list) {
+		pool = container_of(item, PgPool, head);
+		if (pool->db->host && strcmp(host, pool->db->host) == 0) {
+			for_each_server_filtered(pool, tag_dirty, server_remote_addr_filter, &addr);
+		}
+	}
+}
+
+
 /* move objects from justfree_* to free_* lists */
 void reuse_just_freed_objects(void)
 {
